Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(88)

Unified Diff: ash/display/window_tree_host_manager_unittest.cc

Issue 2215223004: mash: Migrate ShelfLayoutManager ScreenUtil usage to ash common types. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Restore screen bounds conversion for app list. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/common/wm_shell.h ('k') | ash/mus/bridge/wm_shell_mus.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/display/window_tree_host_manager_unittest.cc
diff --git a/ash/display/window_tree_host_manager_unittest.cc b/ash/display/window_tree_host_manager_unittest.cc
index a754e19e3bf70a61f2be0b911d77cda9dc8967df..dd481bb0d55f415dd4a56c3d9b3213548fb9ed0a 100644
--- a/ash/display/window_tree_host_manager_unittest.cc
+++ b/ash/display/window_tree_host_manager_unittest.cc
@@ -6,11 +6,13 @@
#include <memory>
+#include "ash/aura/wm_window_aura.h"
#include "ash/common/ash_switches.h"
#include "ash/common/display/display_info.h"
#include "ash/common/material_design/material_design_controller.h"
#include "ash/common/wm/window_state.h"
#include "ash/common/wm/wm_event.h"
+#include "ash/common/wm/wm_screen_util.h"
#include "ash/display/display_layout_store.h"
#include "ash/display/display_manager.h"
#include "ash/display/display_util.h"
@@ -1297,7 +1299,8 @@ class RootWindowTestObserver : public aura::WindowObserver {
void OnWindowBoundsChanged(aura::Window* window,
const gfx::Rect& old_bounds,
const gfx::Rect& new_bounds) override {
- shelf_display_bounds_ = ScreenUtil::GetShelfDisplayBoundsInRoot(window);
+ shelf_display_bounds_ =
+ wm::GetDisplayBoundsWithShelf(WmWindowAura::Get(window));
}
const gfx::Rect& shelf_display_bounds() const {
@@ -1312,8 +1315,8 @@ class RootWindowTestObserver : public aura::WindowObserver {
} // names
// Make sure that GetShelfDisplayBoundsInRoot returns the correct bounds
// when primary display gets replaced in a following scenario.
// 1) Two displays connected: a) b)
// 2) both are disconnected and new one with the same size as b) is connected
// in one configuration event.
@@ -1312,8 +1315,8 @@ class RootWindowTestObserver : public aura::WindowObserver {
} // names
-// Make sure that GetShelfDisplayBoundsInRoot returns the correct bounds
-// when primary display gets replaced in a following scenario.
+// Make sure that GetDisplayBoundsWithShelf returns the correct bounds
+// when the primary display gets replaced in one of the following scenarios:
// 1) Two displays connected: a) b)
// 2) both are disconnected and new one with the same size as b) is connected
« no previous file with comments | « ash/common/wm_shell.h ('k') | ash/mus/bridge/wm_shell_mus.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698